@@ -803,7 +803,7 @@ public String getSystemId() { return lexer.getSystemID(); }
 private class StartLocator implements org.xml.sax.Locator
 {
     public int getLineNumber ( ) { return Piccolo.this.lexer.tokenStartLine; }
-    public int getColumnNumber ( ) { return Piccolo.this.lexer.tokenStartColumn; }
+    public int getColumnNumber ( ) { return -1; }
     public String getPublicId ( ) { return null; }
     public String getSystemId ( ) { return null; }
 }
