@@ -374,13 +374,15 @@ public final class GDateBuilder implements GDateSpecification, java.io.Serializa
     public final int getTimeZoneMinute()
         { return _tzm; }
 
+    
+
     /**
      * Sets the year. Should be a four-digit year specification.
      * @param year the year
      */
     public void setYear(int year)
     {
-        if (year < -4713 || year > 999999)
+        if (year < GDate.MIN_YEAR || year > GDate.MAX_YEAR)
             throw new IllegalArgumentException("year out of range");
         if (year == 0)
             throw new IllegalArgumentException("year cannot be 0");
@@ -414,14 +416,14 @@ public final class GDateBuilder implements GDateSpecification, java.io.Serializa
      * minutes and seconds range from 0 to 59; and fractional
      * seconds range from 0 (inclusive) to 1 (exclusive).
      * The fraction can be null and is assumed to be zero.
-     * @param hour the hour of day, from 0-23
+     * @param hour the hour of day, from 0-23 or 24 only if min, sec and fraction are 0
      * @param minute the minute of hour, from 0-59
      * @param second the second of minute, from 0-59
      * @param fraction the fraction of second, 0.0 to 0.999... (may be null)
      */
     public void setTime(int hour, int minute, int second, BigDecimal fraction)
     {
-        if (hour < 0 || hour > 23)
+        if (hour < 0 || hour > 24 )
             throw new IllegalArgumentException("hour out of range");
         if (minute < 0 || minute > 59)
             throw new IllegalArgumentException("minute out of range");
@@ -429,6 +431,9 @@ public final class GDateBuilder implements GDateSpecification, java.io.Serializa
             throw new IllegalArgumentException("second out of range");
         if (fraction != null && (fraction.signum() < 0 || fraction.compareTo(GDate._one) > 1))
             throw new IllegalArgumentException("fraction out of range");
+        if ( hour == 24 && (minute!=0 || second!=0 || (fraction!=null && (GDate._zero.compareTo(fraction)!=0)) ))
+            throw new IllegalArgumentException("when hour is 24, min sec and fracton must be 0");
+
         _bits |= HAS_TIME;
         _h = hour;
         _m = minute;
@@ -561,10 +566,13 @@ public final class GDateBuilder implements GDateSpecification, java.io.Serializa
               date.getDay() > _maxDayInMonth(date.getMonth()))))
             return false;
 
-        if (date.hasTime() && (date.getHour() < 0 || date.getHour() > 23 ||
+        if (date.hasTime() && ((date.getHour() < 0 || date.getHour() > 23 ||
             date.getMinute() < 0 || date.getMinute() > 59 ||
             date.getSecond() < 0 || date.getSecond() > 59 ||
-            date.getFraction().signum() < 0 || date.getFraction().compareTo(GDate._one) >= 0))
+            date.getFraction().signum() < 0 || date.getFraction().compareTo(GDate._one) >= 0)  ) &&
+            // check for 24:00:00 valid format
+            !(date.getHour() == 24 && date.getMinute() == 0 && date.getSecond() == 0 &&
+              date.getFraction().compareTo(GDate._zero) == 0 ) )
             return false;
 
         if (date.hasTimeZone() &&
@@ -596,37 +604,14 @@ public final class GDateBuilder implements GDateSpecification, java.io.Serializa
         // DateTime or Time, with TimeZone: normalize to UTC.
         // In the process all the fields will be normalized.
         if (hasDay() == hasMonth() && hasDay() == hasYear() &&
-            hasTimeZone() && hasTime())
+            hasTimeZone() && hasTime() )
         {
             normalizeToTimeZone(0, 0, 0);
         }
         else
         {
             // No timezone, or incomplete date.
-            long carry = 0;
-
-            if (hasTime())
-                carry = _normalizeTime();
-
-            if (hasDay())
-                _D += carry;
-
-            if (hasDate())
-            {
-                _normalizeDate();
-            }
-            else if (hasMonth())
-            {
-                // with incomplete dates, just months can be normalized:
-                // days stay denormalized.
-                if (_M < 1 || _M > 12)
-                {
-                    int temp = _M;
-                    _M = _modulo(temp, 1, 13);
-                    if (hasYear())
-                        _CY = _CY + (int)_fQuotient(temp, 1, 13);
-                }
-            }
+            _normalizeTimeAndDate();
         }
 
         // remove trailing zeros from fractional seconds
@@ -648,6 +633,46 @@ public final class GDateBuilder implements GDateSpecification, java.io.Serializa
         }
     }
 
+   /**
+     * Normalizes the instance when hour is 24. If day is present, hour 24 is equivalent to hour 00 next day.
+     */
+    void normalize24h()
+    {
+        if ( !hasTime() || getHour()!=24 )
+            return;
+
+        _normalizeTimeAndDate();
+    }
+
+
+    private void _normalizeTimeAndDate()
+    {
+        long carry = 0;
+
+        if (hasTime())
+            carry = _normalizeTime();
+
+        if (hasDay())
+            _D += carry;
+
+        if (hasDate())
+        {
+            _normalizeDate();
+        }
+        else if (hasMonth())
+        {
+            // with incomplete dates, just months can be normalized:
+            // days stay denormalized.
+            if (_M < 1 || _M > 12)
+            {
+                int temp = _M;
+                _M = _modulo(temp, 1, 13);
+                if (hasYear())
+                    _CY = _CY + (int)_fQuotient(temp, 1, 13);
+            }
+        }
+    }
+
     /**
      * If the time and timezone are known, this method changes the timezone to the
      * specified UTC offset, altering minutes, hours, day, month, and year as
